@@ -1,9 +1,9 @@
 #
-# $Id: Split.pm,v 0.40 2004/01/05 12:15:36 sts Exp $
+# $Id: Split.pm,v 0.41 2004/01/05 12:15:36 sts Exp $
 
 package Dir::Split;
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 use 5.6.1;
 use strict;
@@ -99,7 +99,7 @@ which will influence the splitting process.
 
 sub new {
     my ($pkg, $Opt_ref) = @_;
-    croak q~usage: Dir::Split->new (\%options)~
+    croak q~Usage: Dir::Split->new (\%options)~
       unless ref $Opt_ref eq 'HASH';
 
     my $class = ref ($pkg) || $pkg;
@@ -159,7 +159,7 @@ Split files to subdirectories.
 It is of tremendous importance to notice that checking the return code is a B<must>.
 Leaving the return code untouched will not allow appropriate gathering of harmless
 debug data (such as existing files) and system operations that failed. C<Dir::Split>
-does only report verbose output of mkpath to STDOUT. See I<OPTIONS / debug> on how to
+does only report verbose output of mkpath to STDOUT. See B<OPTIONS / debug> on how to
 become aware of existing files and failed system operations (I<copy> & I<unlink>).
 
 B<RETURN CODES>
@@ -178,13 +178,13 @@ No action.
 
 Exists.
 
-I<(see OPTIONS / debug / existing)>.
+I<(see OPTIONS / debug / existing)>
 
 =item (-2)
 
 Failure.
 
-I<(see OPTIONS / debug / failures)>.
+I<(see OPTIONS / debug / failures)>
 
 =back
 
@@ -385,7 +385,7 @@ sub _suffix_num_sum_up {
 #
 # _suffix_char()
 #
-# Evaluates filenames and stores them 
+# Evaluates filenames and stores them
 # in a hash associated with the leading
 # characters of their filenames.
 #
@@ -470,9 +470,9 @@ sub _dir_read {
     shift; my ($dir, $files_ref) = @_;
 
     opendir D, $dir
-      or croak qq~could not open dir $dir for read-access: $!~;
+      or croak qq~Could not open dir $dir for read-access: $!~;
     @$files_ref = readdir D; splice @$files_ref, 0, 2;
-    closedir D or croak qq~could not close dir $dir: $!~;
+    closedir D or croak qq~Could not close dir $dir: $!~;
 }
 
 #
@@ -488,7 +488,7 @@ sub _mkpath {
 
     return if -e $Path;
     mkpath $Path, $o->{'verbose'} or
-      croak qq~dir $Path could not be created: $!~;
+      croak qq~Dir $Path could not be created: $!~;
 
     $track{'target'}{'dirs'}++;
 }
@@ -791,7 +791,7 @@ Above example: directory consisting 512 files successfully splitted to 128 direc
 
 =head3 existing
 
-If C<split()> returns a I<EXISTS>, this implys that the B<override> option is disabled and
+If C<split()> returns a EXISTS, this implys that the B<override> option is disabled and
 files weren't moved due to existing files within the target subdirectories; they will have
 their paths appearing in C<@Dir::Split::exists>.
 
@@ -800,7 +800,7 @@ their paths appearing in C<@Dir::Split::exists>.
 
 =head3 failures
 
-If C<split()> returns a I<FAILURE>, this most often implys that the B<override> option is enabled
+If C<split()> returns a FAILURE, this most often implys that the B<override> option is enabled
 and existing files could not be overriden. Files that could not be copied / unlinked,
 will have their paths appearing in the according keys in C<%Dir::Split::failure>.
 
@@ -810,12 +810,13 @@ will have their paths appearing in the according keys in C<%Dir::Split::failure>
            @{$Dir::Split::failure{'unlink'}}    # files that could be copied but not unlinked,
                                                 # rather seldom.
 
-It is recommended to evaluate those arrays on I<FAILURE>. A C<@Dir::Split::exists> array
-may coexist.
+It is recommended to evaluate those arrays on FAILURE.
+
+A C<@Dir::Split::exists> array may coexist.
 
 =head1 EXAMPLES
 
-Assuming I</source> contains 5 files:
+Assuming F</source> contains 5 files:
 
     +- _12.tmp
     +- abc.tmp
@@ -823,7 +824,7 @@ Assuming I</source> contains 5 files:
     +- ghi.tmp
     +- jkl.tmp
 
-After splitting the directory tree in I</target> will look as following:
+After splitting the directory tree in F</target> will look as following:
 
 B<numeric splitting>
 
@@ -863,7 +864,7 @@ like overriding, are disabled.
 =item B<Portability?>
 
 Has not yet been extensively tested. C<Dir::Split>
-relies mostly upon File:: nested modules in spite of
+relies mostly upon C<File::> nested modules in spite of
 filesystem operations such as copying, unlinking and
 selecting an appropriate path separator; thus it should
 probably be portable.
